==> deepin-appstore_5.3.0.1.orig.tar.xz: deepin-appstore-5.3.0.1/translations/deepin-appstore_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="115"/>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="164"/>
        <source>Search &quot;%1&quot; in Deepin Store</source>
        <translation>Pesquisar por &quot;%1&quot; na Deepin Store</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar.cpp" line="206"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="55"/>
        <source>Recommend App</source>
        <translation>Recomendar Aplicação</translation>
    </message>
    <message>
        <source>Select region</source>
        <translation type="vanished">Selecione a região</translation>
    </message>
    <message>
        <source>China</source>
        <translation type="vanished">China</translation>
    </message>
    <message>
        <source>International</source>
        <translation type="vanished">Internacional</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="60"/>
        <source>Clear cache</source>
        <translation>Limpar cache</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="64"/>
        <source>Dark theme</source>
        <translation>Tema escuro</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="70"/>
        <source>Privacy Policy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="73"/>
        <source>Undo</source>
        <translation>Anular</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="78"/>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="84"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="89"/>
        <location filename="../src/ui/web_event_delegate.cpp" line="113"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="94"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="99"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="105"/>
        <source>Select all</source>
        <translation>Selecionar todos</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_appstore.cpp" line="107"/>
        <source>Deepin Store</source>
        <translation>Deepin Store</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_appstore.cpp" line="108"/>
        <source>Deepin Store is an App Store with diverse and quality applications. It features popular recommendations, newly updated apps and hot topics, and supports one-click installation, updating and uninstalling.</source>
        <translation>A Loja Deepin é uma Loja de aplicações com diversas aplicações de qualidade. Ela apresenta recomendações populares, aplicações atualizadas recentemente e tópicos ativos e suporta instalação, atualização e desinstalação com apenas um clique.</translation>
    </message>
</context>
<context>
    <name>dstore::UserMenu</name>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="13"/>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="16"/>
        <source>My comments</source>
        <translation>Meus comentários</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="20"/>
        <source>My donations</source>
        <translation>Minhas doações</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="24"/>
        <source>My apps</source>
        <translation>Minhas aplicações</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="30"/>
        <source>Sign out</source>
        <translation>Sair</translation>
    </message>
</context>
</TS>

==> deepin-appstore_5.3.1.5.orig.tar.xz: deepin-appstore-5.3.1.5/translations/deepin-appstore_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="115"/>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="164"/>
        <source>Search &quot;%1&quot; in Deepin Store</source>
        <translation>Pesquisar por &quot;%1&quot; na Deepin Store</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar.cpp" line="206"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="55"/>
        <source>Recommend App</source>
        <translation>Recomendar Aplicação</translation>
    </message>
    <message>
        <source>Select region</source>
        <translation type="vanished">Selecione a região</translation>
    </message>
    <message>
        <source>China</source>
        <translation type="vanished">China</translation>
    </message>
    <message>
        <source>International</source>
        <translation type="vanished">Internacional</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="60"/>
        <source>Clear cache</source>
        <translation>Limpar cache</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="64"/>
        <source>Dark theme</source>
        <translation>Tema escuro</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="70"/>
        <source>Privacy Policy</source>
        <translation>Política de privacidade</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="73"/>
        <source>Undo</source>
        <translation>Anular</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="78"/>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="84"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="89"/>
        <location filename="../src/ui/web_event_delegate.cpp" line="113"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="94"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="99"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="105"/>
        <source>Select all</source>
        <translation>Selecionar todos</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_appstore.cpp" line="107"/>
        <source>Deepin Store</source>
        <translation>Loja Deepin</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_appstore.cpp" line="108"/>
        <source>Deepin Store is an App Store with diverse and quality applications. It features popular recommendations, newly updated apps and hot topics, and supports one-click installation, updating and uninstalling.</source>
        <translation>A Loja Deepin é uma Loja de aplicações com diversas aplicações de qualidade. Ela apresenta recomendações populares, aplicações atualizadas recentemente e tópicos ativos e suporta instalação, atualização e desinstalação com apenas um clique.</translation>
    </message>
</context>
<context>
    <name>dstore::UserMenu</name>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="13"/>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="16"/>
        <source>My comments</source>
        <translation>Meus comentários</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="20"/>
        <source>My donations</source>
        <translation>Minhas doações</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="24"/>
        <source>My apps</source>
        <translation>Minhas aplicações</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="30"/>
        <source>Sign out</source>
        <translation>Sair</translation>
    </message>
</context>
</TS>
